# CSS Dynamic Conditions
Sometimes you want to apply some CSS rules only in response to user interaction, in order to highlight or even reveal information. This specification describes a way to achieve this in pure CSS, without needing to write event handlers and in a way which naturally degrades to non-interactive stylesheets.

## `@@while` rules
`@@while` can occur in stylesheets for supporting user agents, and will be ignored by non-supporting ones. It follows this syntax (specified using Extended Backus Neur Form):

    "@@while" "(" SELECTOR ")" ["[" CONDITION "]"] (":" RULE | "{" RULE* "}")

Upon encountering this a supporting user agent MUST only apply the `RULE`s iff there exists an element currently on the page which matches `SELECTOR` and the `CONDITION`, if specified, is true. Once this no longer the case a user agent MUST no longer applies these rules.

### Element Variables
In an `@@while`'s SELECTOR, elements can be "captured" for the condition by adding to it's simple selector a `$`-prefixed identifier. These identifiers can then be referred to by the `CONDITION`. If the simple selector might match multiple elements in the process of matching the complex selector, it SHOULD match all of them.

### Conditions
The CONDITION for an `@@while` selector may use the same operators as CSS3 media queries. However the identifiers they can test against differs, most of which follow the form `ELEMENT-BOX-SIDE`. Where ELEMENT refers to a logic variable from the selector or can be "viewbox" to refer to the box to which the page is clipped for display, BOX can be one of "padding", "border", "margin", or "content", and SIDE can be "top", "left", "bottom", or "right". The meaning of the latter two are taken from the CSS box model. SIDE can also be "x" or "y" in which they take on the range of values between "left" and "right" or "top" and "bottom" respectively.

If ELEMENT is not specified, it MUST default to the elements matched by the complex selector (in other words the rightmost simple selector). If BOX is not specified it MUST default to "content". And if SIDE is not specified, it MUST default to "y".

Additionally the keywords "mouse-x" and "mouse-y" may be used to refer to the position of the cursor, if known to the user agent.

The condition SHOULD pass if it passes for any of the values of the variables.

#### Impact on layout
The user agent MUST not reposition or resize any elements in response to applying style rules from an `@@while` rule which specifies a layout condition. Logic variables are not valid in a condition. 

### Logic Variables
The attribute selector is extended in relation to `@@while` rules so that attribute can be tested for equality against a sequence of `$`-prefixed identifiers and strings. These sequences MUST start with a string, which MAY be empty.

In the test selector, these identifiers take on all possible values they can in order to concatenate with the strings and other logical variables to match the attribute. If this isn't possible the selector fails.

In the embedded style rules they refer to their captured values, concatenating with any other logic variables and text to construct values to be tested against.

### `:last-match`, `:first-match`
The `:last-match` psuedoclass matches an element if it is the last element in page-order which matches the rest of the selector, considering all logic variable values provided by the containing `@@while` rule. `:first-match` matches if it's the first element which matches the selector, in the same way `:last-match` matches the last element.

## Other dynamic at-rules
Additional at-rules are specified in this document in order to ease the development of simpler user interfaces. Logic variables in attribute selectors, `:last-match`, and `:first-match` are valid for these too.

### `@@toggled`
`@@toggled` is written in the form `"@@toggled" ("on"|"off") "(" SELECTOR ")" (":" RULE | "{" RULE* "}")`. The keywords "on" or "off" specifies if the `RULE`s SHOULD apply by default. Then once any elements matched by `SELECTOR` are "activated" by the user (as determined by the user agent) the `RULE`s should alternate being enabled or disabled.

### `@@on`
`@@on` is written in the form `"@@on" "(" SELECTOR ")" (":" RULE | "{" RULE* "}")`. Once an element matches SELECTOR the `RULE`s are applied, and are not disabled once the SELECTOR stops matching.

## Security Concerns
* If url() functions are resolved lazily, it's possible for servers to track the user's interactions. These URLs SHOULD be resolved eagerly while the CSS is being parsed.
* If position tests were allowed to trigger a relayout, that would trigger a significant loss of performance user agents SHOULD prevent.
* Worse it's possible that if logic variables were captured from position conditions as well, that webpages could execute arbitrary computations which may or may not be malicious.
* Any other Turing Completeness concerns? It doesn't take much to fall into that trap.

## TODO
* Cleanup specification to make it more normative.