# Hypertext Advanced Targets - Polling
Websites may wish to present information that is most useful when kept up to date, however allowing them to repeatedly download new content from a webserver might let them invade a user's privacy.

This specification defines a declarative way for webpages to poll a server for updates to a target element, which user agents can let users opt into in their own time. It also defines a means of triggering notifications from the markup being downloaded via polling.

## Additional `<a>` attributes
Upon encountering a `poll` attribute on an `<a>` element, it should be parsed as a CSS time unit optionally followed by whitespace and the keyword `notify`. This hyperlink must also specify an [advanced target](https://tildegit.org/alcinnz/PostJS/src/branch/master/drafts/hyperlinks-advanced-targets.md), which MUST be resolved when the polling for that link is first activated.

Once it's been parsed, the user agent MUST offer to load that link as according to [Hypertext Advanced Targets](https://tildegit.org/alcinnz/PostJS/src/branch/master/drafts/hyperlinks-advanced-targets.md) at the specified frequency, optionally allowing users to alter these parameters. The handling of the `notify` keyword in the section "Notifications".

## `X-HTML-Poll` HTTP response header
The `X-HTML-Poll` HTTP response header extends the [Hypertext Advanced Targets](https://tildegit.org/alcinnz/PostJS/src/branch/master/drafts/hyperlinks-advanced-targets.md) response handling, and effects any elements if any that was loaded from a polled request whilst containing the target element.

It can contain the following the following values:

* `pause` - prevents requests being sent until a `resume` instruction is received.
* `resume` - resumes requests for any previously `pause`d polling.
* A floating point number - sets a new polling frequency in seconds, if the specified frequency is less frequent than was agreed to in the confirmation.

## Notifications
If the user has opted into it, user agents MAY scan the HTML snippets received from the polling requests for elements with `notify` attributes.

Upon encountering one information SHOULD be extracted from the element's children according to the HTML semantics and somehow brought to the user's attention.

## Security
There are two main concerns around allowing websites to send requests periodically rather than in response to user interaction. The first is that doing so may be used to upload additional information to the webserver. The second is that it can be used to waste their internet bandwidth.

So user agents MUST:

* Make sure the live updates are something the user wants.
* Prevent more frequent updates than was agreed to.
* Only allow links to poll the server, so users can be confident it isn't uploading their form data as well.

Furthermore when notifications are introduced, they provide a means for websites to invade a user's attention. Which is something they may or may not want, and as such requires confirmation.