# Hyperlink Advanced Targets - Storage
It is often useful for websites to store user preferences, draft data, etc on the client machine. But at the same time existing facilities allowing this are routinely used to "track" users accross different websites. This specification defines a declarative alternative to cookies or localstorage which allows users to better control what data is sent where.

## The local database
Each domain name and protocol schema pair gets their own key-value database.

### Database legends
A host MAY opt to publish a document at the relative URL `/.well-known/local-storage.txt`. This file should consist of a number of lines specifying an identifier followed by a tab and then a human readable label. Any lines prefixed by a `#` MUST be ignored. It SHOULD be served with the MIME type `text/plain`.

It is not considered a vulnerability that the website is allowed to specify the human readable labels, because they also specify the machine readable identifiers. As such this file can only be used to improve privacy, not degrade it.

## The `localvars` attribute (reading data)
When a link, form, or any element with a [hyperlink advanced target](https://tildegit.org/alcinnz/PostJS/src/branch/master/drafts/hyperlinks-advanced-targets.md) which has a `localvars` attribute is activated, the URL should be adjusted each time as described here.

It MUST be parsed as whitespace-seperated identifiers, each of which MUST be looked up in the database for the target URL and tacked on as a query parameter.

## `X-HTML-SetVar` HTTP response header (writing data)
If an HTTP request contains the `X-HTML-SetVar` HTTP response header, it's value should be parsed as a set of query parameters as if in a URL. Each parsed query parameter MUST then be stored in the database for the site providing this HTTP response.

## Security
There are a number of security concerns that come with allowing remote "servers" store data on your local computer.

### Malware distribution
User agents MUST take measures to prevent any of this data from being executed.

### Tracking
A unique identifier can be stored on the client in order to inform webservers that all the requests came from the same person. In some cases this can be useful, as is the case for user accounts. But in others it can be concerning, so users MUST be informed about the attached data.

This can be even more concerning when sites coordinate their databases to get a more in depth profile of the user, and as such each site's databases MUST be kept strictly seperate.

### Confidentiality
Users may utilise the web to interact with businesses with which they have a confidential relationship to, e.g. banks, eMail. These websites would be very concerned if other sites could read their data.