# Advanced Hypertext Targets
By far the most dominant use of JavaScript today is for asynchronously sending requests for data to render into the webpage, a.k.a. Ajax. The benefit being that it allows the surfer to do other stuff on the page whilst the request is inflight. For JavaScript to be deprecated, this need must be satisfied.

As such this document proposes that hyperlinks should be configurable to parse their response as an HTML snippet and insert it into a specified element. And a way to specify form controls whose value should be included in the request.



## Out of scope
The spec for this should not include a means of polling the server, or a means to attach locally stored information to the request. Those deserve their own specifications and both of which are implemented by our Intercooler inspiration.

## Case studies
* https://mastodon.social/
* https://duckduckgo.com/ - This is an interesting case because they use Ajax so the page doesn't take as long to download as it's slowest data request.
* [https://www.techdirt.com/articles/20181111/09191641022/funniest-most-insightful-comments-week-techdirt.shtml](https://www.techdirt.com/articles/20181111/09191641022/funniest-most-insightful-comments-week-techdirt.shtml) - The comment section.

## Prior Work
* https://john.ankarstrom.se/english/texts/replacing-javascript/
* http://intercoolerjs.org/ - This spec will likely be based in large part on this framework.
* https://www.w3.org/TR/html52/links.html#links
* [https://www.w3.org/TR/html52/sec-forms.html#forms-form-submission](https://www.w3.org/TR/html52/sec-forms.html#forms-form-submission)

## Concerns
* Each (batch of) request must be sent only with informed and explicit permission from the surfer.
* Only &lt;a&gt;, &lt;button&gt;, and form inputs should be capable of triggering these requests, in order to increase clarity and cater to a wider range of UI devices.
* Only form elements should be able to upload data from their corresponding form, in order to increase clarity and cater to a wider range of UI devices.
* This spec should gracefully degrade to hyperlinks and forms as defined today.
* Post-JS browsers should not need to implement separate code paths for traditional hyperlinks and forms, as opposed to these more advanced variants.
* Changes via this standard should not be able to impact pages within iframes.

### UI Devices
* Touchscreen inputs are concerning because they have near no chance to inform readers of a link's actions before they follow it. Everything must be communicated statically on the page.
* Accessible UI devices like braille teletypes or voice assistants may prefer to treat these links as navigations to new pages rather than have to cope with a changing UI.
* Some devices may prefer to present a new page rather than a change in the document.