# Conditional CSS
One common use of JavaScript since the beginning was to dynamically change a page's styling based upon user interaction. Thereby creating navigation menus, accordians, lightboxes, treeviews, etc.

So I propose that CSS should be extended such that style rules can be made conditional on the presence of another selector's presence. And optionally the position onscreen of the elements upon which it's conditional. The latter would be useful e.g. for highlighting links in a table of contents.

## Case Studies
* &lt;detail&gt; element
* "Accordian" controls
* hamburger menus
* https://john.ankarstrom.se/english/texts/replacing-javascript/#css-examples

## Prior Work
* https://john.ankarstrom.se/english/texts/replacing-javascript/#css-examples
* https://www.w3.org/TR/css-syntax-3/

## Concerns
* The spec should be defined such that non-supporting browsers will just ignore the conditional styles, and not the whole stylesheet.
* This spec should only be useful for changing the display, not retrieving information from the client.
* Browsers should be free to choose not to implement this, if it doesn't work well with their UI devices.

### Required clarifications
* When should selector variables (as defined by Ankarstrom) be captured?
    * They should be captured exclusively via attribute selectors of the parent in order to minimize complexity.
* How should layout conditions work?
    * Conditions on numbers from the box-model would be intuitive.
    * Conditions on ranges would be convenient without introducing much additional complexity.
    * Should be safe to test relative positions between elements, the viewport, and/or the cursor.
    * Need to be cautious if these conditons can be used to impact where things are positioned AND these new positions can be tested against in another styling pass. That starts to at least resemble Turing Completeness.
* Ankarstrom suggested that having three variants (`while` which would be deactivated when the condition selector no longer matches, `on` which would not deactivate, and `toggled-by` which would deactivate when the selector next matches). Can we establish what these needs are?
* How to handle relayout after adding new styles based on computed position?
    * I (Adrian Cochrane) would for simplicity suggest it shouldn't relayout.